Index: branches/2.8.x/CHANGELOG
===================================================================
--- branches/2.8.x/CHANGELOG	(revision 1886)
+++ branches/2.8.x/CHANGELOG	(revision 1887)
@@ -11,7 +11,10 @@
 ! = Update/Change
 ===============================================================================
 
-12 Mar-2013 Build 1885 Dietmar Woellbrink (Luisehahne)
+12 Mar-2013 Build 1887 Dietmar Woellbrink (Luisehahne)
+# bugfix Notice: Constant messages during new WB installation
+! update WbDatabase SqlImport parameter, 
+12 Mar-2013 Build 1886 Dietmar Woellbrink (Luisehahne)
 ! Install update, Split Step1+2 from the inputs Steps
 # Languages Typofix
 ! check tables remove not needed tables 
Index: branches/2.8.x/wb/admin/interface/version.php
===================================================================
--- branches/2.8.x/wb/admin/interface/version.php	(revision 1886)
+++ branches/2.8.x/wb/admin/interface/version.php	(revision 1887)
@@ -51,5 +51,5 @@
 
 // check if defined to avoid errors during installation (redirect to admin panel fails if PHP error/warnings are enabled)
 if(!defined('VERSION')) define('VERSION', '2.8.3');
-if(!defined('REVISION')) define('REVISION', '1886');
+if(!defined('REVISION')) define('REVISION', '1887');
 if(!defined('SP')) define('SP', '');
Index: branches/2.8.x/wb/framework/initialize.php
===================================================================
--- branches/2.8.x/wb/framework/initialize.php	(revision 1886)
+++ branches/2.8.x/wb/framework/initialize.php	(revision 1887)
@@ -78,12 +78,12 @@
 			$x1 = parse_url(WB_URL);
 			define('WB_REL', (isset($x1['path']) ? $x1['path'] : ''));
 		}
-		define('ADMIN_REL', WB_REL.'/'.ADMIN_DIRECTORY);
+		if(!defined('ADMIN_REL')){ define('ADMIN_REL', WB_REL.'/'.ADMIN_DIRECTORY); }
 		if(!defined('DOCUMENT_ROOT')) {
 			
 			define('DOCUMENT_ROOT', preg_replace('/'.preg_quote(WB_REL, '/').'$/', '', WB_PATH));
 		}
-		define('TMP_PATH', WB_PATH.'/temp');
+		if(!defined('TMP_PATH')){ define('TMP_PATH', WB_PATH.'/temp'); }
 	}
 /**
  * Read DB settings from configuration file
@@ -117,6 +117,7 @@
 				switch($key):
 					case 'DEBUG':
 						$value = filter_var($value, FILTER_VALIDATE_BOOLEAN);
+						if(!defined('DEBUG')) { define('DEBUG', $value); }
 						break;
 					case 'WB_URL':
 					case 'AppUrl':
@@ -143,7 +144,7 @@
 			$db['name'] = isset($db['name']) ? $db['name'] : 'dummy';
 			$db['charset'] = isset($db['charset']) ? $db['charset'] : 'utf8';
 			$db['table_prefix'] = (isset($db['table_prefix']) ? $db['table_prefix'] : '');
-			define('TABLE_PREFIX', $db['table_prefix']);
+			if(!defined('TABLE_PREFIX')) { define('TABLE_PREFIX', $db['table_prefix']); }
 			if($sRetvalType == 'dsn') {
 				$aRetval[0] = $db['type'].':dbname='.$db['name'].';host='.$db['host'].';'
 				            . ($db['port'] != '' ? 'port='.(int)$db['port'].';' : '');
@@ -232,22 +233,22 @@
 			switch($sSettingName):
 				case 'STRING_FILE_MODE':
 					$iTmp = ((intval(octdec($aSetting['value'])) & ~0111)|0600);
-					define('OCTAL_FILE_MODE', $iTmp);
-					define('STRING_FILE_MODE', sprintf('0%03o', $iTmp));
+					if(!defined('OCTAL_FILE_MODE')) { define('OCTAL_FILE_MODE', $iTmp); }
+					if(!defined('STRING_FILE_MODE')) { define('STRING_FILE_MODE', sprintf('0%03o', $iTmp)); }
 					break;
 				case 'STRING_DIR_MODE':
 					$iTmp = (intval(octdec($aSetting['value'])) |0711);
-					define('OCTAL_DIR_MODE', $iTmp);
-					define('STRING_DIR_MODE', sprintf('0%03o', $iTmp));
+					if(!defined('OCTAL_DIR_MODE')) { define('OCTAL_DIR_MODE', $iTmp); }
+					if(!defined('STRING_DIR_MODE')) { define('STRING_DIR_MODE', sprintf('0%03o', $iTmp)); }
 					break;
 				case 'PAGES_DIRECTORY':
 					// sanitize pages_directory
 					$sTmp = trim($aSetting['value'], '/');
 					$sTmp = ($sTmp == '' ? '' : '/'.$sTmp);
-					define('PAGES_DIRECTORY', $sTmp);
+					if(!defined('PAGES_DIRECTORY')) { define('PAGES_DIRECTORY', $sTmp); }
 					break;
 				default: // make global const from setting
-					@define($sSettingName, $aSetting['value']);
+					if(!defined($sSettingName)) { define($sSettingName, $aSetting['value']); }
 					break;
 			endswitch;
 		}
@@ -266,16 +267,16 @@
 		define('SESSION_STARTED', true);
 	}
 // get/set users timezone ---
-	define('TIMEZONE',    (isset($_SESSION['TIMEZONE'])    ? $_SESSION['TIMEZONE']    : DEFAULT_TIMEZONE));
-	define('DATE_FORMAT', (isset($_SESSION['DATE_FORMAT']) ? $_SESSION['DATE_FORMAT'] : DEFAULT_DATE_FORMAT));
-	define('TIME_FORMAT', (isset($_SESSION['TIME_FORMAT']) ? $_SESSION['TIME_FORMAT'] : DEFAULT_TIME_FORMAT));
+	if(!defined('TIMEZONE')) { define('TIMEZONE', (isset($_SESSION['TIMEZONE']) ? $_SESSION['TIMEZONE'] : DEFAULT_TIMEZONE)); }
+	if(!defined('DATE_FORMAT')) { define('DATE_FORMAT', (isset($_SESSION['DATE_FORMAT']) ? $_SESSION['DATE_FORMAT'] : DEFAULT_DATE_FORMAT)); }
+	if(!defined('TIME_FORMAT')) { define('TIME_FORMAT', (isset($_SESSION['TIME_FORMAT']) ? $_SESSION['TIME_FORMAT'] : DEFAULT_TIME_FORMAT)); }
 // set Theme directory --- 
-	define('THEME_URL',  WB_URL.'/templates/'.DEFAULT_THEME);
-	define('THEME_PATH', WB_PATH.'/templates/'.DEFAULT_THEME);
-	define('THEME_REL',  WB_REL.'/templates/'.DEFAULT_THEME);
+	if(!defined('THEMA_URL')) { define('THEME_URL',  WB_URL.'/templates/'.DEFAULT_THEME); }
+	if(!defined('THEME_PATH')) { define('THEME_PATH', WB_PATH.'/templates/'.DEFAULT_THEME); }
+	if(!defined('THEME_REL')) { define('THEME_REL',  WB_REL.'/templates/'.DEFAULT_THEME); }
 // extended wb editor settings
-	define('EDIT_ONE_SECTION', false);
-	define('EDITOR_WIDTH', 0);
+	if(!defined('EDIT_ONE_SECTION')) { define('EDIT_ONE_SECTION', false); }
+	if(!defined('EDITOR_WIDTH')) { define('EDITOR_WIDTH', 0); }
 // define form security class and preload it ---
 	$sSecMod = (defined('SECURE_FORM_MODULE') && SECURE_FORM_MODULE != '') ? '.'.SECURE_FORM_MODULE : '';
 	$sSecMod = WB_PATH.'/framework/SecureForm'.$sSecMod.'.php';
@@ -282,7 +283,7 @@
 	require_once($sSecMod);
 // *** begin deprecated part *************************************************************
 // load settings for use in Captch and ASP module
-	if (!defined("WB_INSTALL_PROCESS")) {
+	if (!defined('WB_INSTALL_PROCESS') && !defined('ENABLED_CAPTCHA')) {
 		$sql = 'SELECT * FROM `'.TABLE_PREFIX.'mod_captcha_control`';
 		// request settings from database
 		if(($oSettings = $database->query($sql))) {
Index: branches/2.8.x/wb/install/sql/websitebaker.sql
===================================================================
--- branches/2.8.x/wb/install/sql/websitebaker.sql	(revision 1886)
+++ branches/2.8.x/wb/install/sql/websitebaker.sql	(revision 1887)
@@ -73,7 +73,7 @@
   `custom01` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
   `custom02` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
   PRIMARY KEY (`page_id`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) {TABLE_ENGINE};
 --
 -- Structure of table  '{TABLE_PREFIX}sections'
 --
@@ -87,7 +87,7 @@
   `publ_start` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '0',
   `publ_end` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '0',
   PRIMARY KEY (`section_id`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) {TABLE_ENGINE};
 --
 -- Structure of table  '{TABLE_PREFIX}users'
 --
Index: branches/2.8.x/wb/install/save.php
===================================================================
--- branches/2.8.x/wb/install/save.php	(revision 1886)
+++ branches/2.8.x/wb/install/save.php	(revision 1887)
@@ -43,26 +43,6 @@
  * Set constants for system/install values
  * @throws RuntimeException
  */
-	function _SetInstallPathConstants() {
-		if(!defined('DEBUG')){ define('DEBUG', false); } // normaly set in config file
-		if(!defined('ADMIN_DIRECTORY')){ define('ADMIN_DIRECTORY', 'admin'); }
-		if(!preg_match('/xx[a-z0-9_][a-z0-9_\-\.]+/i', 'xx'.ADMIN_DIRECTORY)) {
-			throw new RuntimeException('Invalid admin-directory: ' . ADMIN_DIRECTORY);
-		}
-		if(!defined('WB_PATH')){ define('WB_PATH', dirname(dirname(__FILE__))); }
-		if(!defined('ADMIN_URL')){ define('ADMIN_URL', WB_URL.'/'.ADMIN_DIRECTORY); }
-		if(!defined('ADMIN_PATH')){ define('ADMIN_PATH', WB_PATH.'/'.ADMIN_DIRECTORY); }
-		if(!defined('WB_REL')){
-			$x1 = parse_url(WB_URL);
-			define('WB_REL', (isset($x1['path']) ? $x1['path'] : ''));
-		}
-		define('ADMIN_REL', WB_REL.'/'.ADMIN_DIRECTORY);
-		if(!defined('DOCUMENT_ROOT')) {
-			
-			define('DOCUMENT_ROOT', preg_replace('/'.preg_quote(WB_REL, '/').'$/', '', WB_PATH));
-		}
-		define('TMP_PATH', WB_PATH.'/temp');
-	}
 
 /**
  * Read DB settings from configuration file
@@ -122,7 +102,7 @@
 			$db['name'] = isset($db['name']) ? $db['name'] : 'dummy';
 			$db['charset'] = isset($db['charset']) ? $db['charset'] : 'utf8';
 			$db['table_prefix'] = (isset($db['table_prefix']) ? $db['table_prefix'] : '');
-			define('TABLE_PREFIX', $db['table_prefix']);
+			if(!defined('TABLE_PREFIX')) {define('TABLE_PREFIX', $db['table_prefix']);}
 			if($sRetvalType == 'dsn') {
 				$aRetval[0] = $db['type'].':dbname='.$db['name'].';host='.$db['host'].';'
 				            . ($db['port'] != '' ? 'port='.(int)$db['port'].';' : '');
@@ -431,7 +411,13 @@
 $sDbConnectType = 'url'; // depending from class WbDatabase it can be 'url' or 'dsn'
 $aSqlData = _readConfiguration($sDbConnectType);
 
-_SetInstallPathConstants();
+//_SetInstallPathConstants();
+//$TABLE_PREFIX = $table_prefix;
+//$WB_PATH = (dirname(dirname(__FILE__)));
+//$ADMIN_PATH = $WB_PATH.'/admin';
+if(!defined('WB_PATH')){ define('WB_PATH', dirname(dirname(__FILE__))); }
+if(!defined('ADMIN_URL')){ define('ADMIN_URL', WB_URL.'/admin'); }
+if(!defined('ADMIN_PATH')){ define('ADMIN_PATH', WB_PATH.'/admin'); }
 
 if(!file_exists(WB_PATH.'/framework/class.admin.php')) {
 	set_error('It appears the Absolute path that you entered is incorrect');
@@ -563,6 +549,7 @@
 	if(!$database->SqlImport($sSqlFileName,TABLE_PREFIX, false)) { set_error($database->get_error()); }
 
 	require_once(WB_PATH.'/framework/initialize.php');
+// 
 // Include WB functions file
 	require_once(WB_PATH.'/framework/functions.php');
 // Re-connect to the database, this time using in-build database class
Index: branches/2.8.x/wb/modules/wysiwyg/sql/mod_wysiwyg.sql
===================================================================
--- branches/2.8.x/wb/modules/wysiwyg/sql/mod_wysiwyg.sql	(revision 1886)
+++ branches/2.8.x/wb/modules/wysiwyg/sql/mod_wysiwyg.sql	(revision 1887)
@@ -1,36 +1,22 @@
 -- phpMyAdmin SQL Dump
--- version 3.4.5
--- http://www.phpmyadmin.net
---
--- Host: localhost
 -- Erstellungszeit: 15. Sep 2012 um 21:37
 -- Server Version: 5.5.16
--- PHP-Version: 5.3.8
-
 SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
-SET time_zone = "+00:00";
-
-
-/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
-/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
-/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
-/*!40101 SET NAMES utf8 */;
-
 -- --------------------------------------------------------
-
+-- Database structure for module 'wysiwyg'
 --
+-- Replacements: {TABLE_PREFIX}, {TABLE_ENGINE}, {TABLE_COLLATION}
+--
+-- --------------------------------------------------------
+--
 -- Tabellenstruktur für Tabelle `mod_wysiwyg`
---
 
 DROP TABLE IF EXISTS `{TABLE_PREFIX}mod_wysiwyg`;
 CREATE TABLE IF NOT EXISTS `{TABLE_PREFIX}mod_wysiwyg` (
   `section_id` int(11) NOT NULL DEFAULT '0',
   `page_id` int(11) NOT NULL DEFAULT '0',
-  `content` longtext NOT NULL,
-  `text` longtext NOT NULL,
+  `content` longtext{TABLE_COLLATION} NOT NULL,
+  `text` longtext{TABLE_COLLATION} NOT NULL,
   PRIMARY KEY (`section_id`)
-) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
-/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
-/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
+) {TABLE_ENGINE};
+-- EndOfFile
\ No newline at end of file
Index: branches/2.8.x/wb/modules/form/sql/form284db.sql
===================================================================
--- branches/2.8.x/wb/modules/form/sql/form284db.sql	(revision 1886)
+++ branches/2.8.x/wb/modules/form/sql/form284db.sql	(revision 1887)
@@ -1,32 +1,16 @@
 -- phpMyAdmin SQL Dump
--- version 3.4.5
--- http://www.phpmyadmin.net
---
--- Host: localhost
 -- Erstellungszeit: 16. Sep 2012 um 03:20
 -- Server Version: 5.5.16
--- PHP-Version: 5.3.8
--- $Id$
-
 SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
-SET time_zone = "+00:00";
-
-
-/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
-/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
-/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
-/*!40101 SET NAMES utf8 */;
-
+-- --------------------------------------------------------
+-- Database structure for module 'form'
 --
--- Datenbank: ``
+-- Replacements: {TABLE_PREFIX}, {TABLE_ENGINE}, {TABLE_COLLATION}
 --
-
 -- --------------------------------------------------------
-
 --
 -- Tabellenstruktur für Tabelle `mod_form_fields`
 --
-
 DROP TABLE IF EXISTS `{TABLE_PREFIX}mod_form_fields`;
 CREATE TABLE IF NOT EXISTS `{TABLE_PREFIX}mod_form_fields` (
   `field_id` int(11) NOT NULL AUTO_INCREMENT,
@@ -33,37 +17,34 @@
   `section_id` int(11) NOT NULL DEFAULT '0',
   `page_id` int(11) NOT NULL DEFAULT '0',
   `position` int(11) NOT NULL DEFAULT '0',
-  `title` varchar(255) NOT NULL DEFAULT '',
-  `type` varchar(255) NOT NULL DEFAULT '',
+  `title` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
+  `type` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
   `required` int(11) NOT NULL DEFAULT '0',
-  `value` text NOT NULL,
-  `extra` text NOT NULL,
+  `value` text{TABLE_COLLATION} NOT NULL,
+  `extra` text{TABLE_COLLATION} NOT NULL,
   PRIMARY KEY (`field_id`)
 ) {TABLE_ENGINE};
-
 -- --------------------------------------------------------
-
 --
 -- Tabellenstruktur für Tabelle `mod_form_settings`
 --
-
 DROP TABLE IF EXISTS `{TABLE_PREFIX}mod_form_settings`;
 CREATE TABLE IF NOT EXISTS `{TABLE_PREFIX}mod_form_settings` (
   `section_id` int(11) NOT NULL DEFAULT '0',
   `page_id` int(11) NOT NULL DEFAULT '0',
-  `header` text NOT NULL,
+  `header` text{TABLE_COLLATION} NOT NULL,
   `field_loop` text NOT NULL,
-  `footer` text NOT NULL,
-  `email_to` text NOT NULL,
-  `email_from` varchar(255) NOT NULL DEFAULT '',
-  `email_fromname` varchar(255) NOT NULL DEFAULT '',
-  `email_subject` varchar(255) NOT NULL DEFAULT '',
-  `success_page` text NOT NULL,
-  `success_email_to` text NOT NULL,
-  `success_email_from` varchar(255) NOT NULL DEFAULT '',
-  `success_email_fromname` varchar(255) NOT NULL DEFAULT '',
-  `success_email_text` text NOT NULL,
-  `success_email_subject` varchar(255) NOT NULL DEFAULT '',
+  `footer` text{TABLE_COLLATION} NOT NULL,
+  `email_to` text{TABLE_COLLATION} NOT NULL,
+  `email_from` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
+  `email_fromname` varchar(255{TABLE_COLLATION}) NOT NULL DEFAULT '',
+  `email_subject` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
+  `success_page` text{TABLE_COLLATION} NOT NULL,
+  `success_email_to` text{TABLE_COLLATION} NOT NULL,
+  `success_email_from` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
+  `success_email_fromname` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
+  `success_email_text` text{TABLE_COLLATION} NOT NULL,
+  `success_email_subject` varchar(255){TABLE_COLLATION} NOT NULL DEFAULT '',
   `stored_submissions` int(11) NOT NULL DEFAULT '0',
   `max_submissions` int(11) NOT NULL DEFAULT '0',
   `perpage_submissions` int(11) NOT NULL DEFAULT '10',
@@ -70,13 +51,10 @@
   `use_captcha` int(11) NOT NULL DEFAULT '0',
   PRIMARY KEY (`section_id`)
 ) {TABLE_ENGINE};
-
 -- --------------------------------------------------------
-
 --
 -- Tabellenstruktur für Tabelle `mod_form_submissions`
 --
-
 DROP TABLE IF EXISTS `{TABLE_PREFIX}mod_form_submissions`;
 CREATE TABLE IF NOT EXISTS `{TABLE_PREFIX}mod_form_submissions` (
   `submission_id` int(11) NOT NULL AUTO_INCREMENT,
@@ -84,12 +62,7 @@
   `page_id` int(11) NOT NULL DEFAULT '0',
   `submitted_when` int(11) NOT NULL DEFAULT '0',
   `submitted_by` int(11) NOT NULL DEFAULT '0',
-  `body` text NOT NULL,
+  `body` text{TABLE_COLLATION} NOT NULL,
   PRIMARY KEY (`submission_id`)
 ) {TABLE_ENGINE};
-
--- --------------------------------------------------------
-
-/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
-/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
-/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
+-- EndOfFile
\ No newline at end of file

Index: branches/2.8.x/wb/framework/WbDatabase.php
===================================================================
--- branches/2.8.x/wb/framework/WbDatabase.php	(revision 1886)
+++ branches/2.8.x/wb/framework/WbDatabase.php	(revision 1887)
@@ -114,8 +114,8 @@
 			throw new WbDatabaseException('Missing parameter: unable to connect database');
 		}
 		$this->_db_handle = @mysql_connect($hostname.$hostport,
-		                                  $username,
-		                                  $password);
+		                                   $username,
+		                                   $password);
 		if(!$this->_db_handle) {
 			throw new WbDatabaseException('unable to connect \''.$scheme.'://'.
 			                           $hostname.$hostport.'\'');
@@ -400,21 +400,25 @@
  * Import a standard *.sql dump file
  * @param string $sSqlDump link to the sql-dumpfile
  * @param string $sTablePrefix
  * @param bool $bPreserve set to true will ignore all DROP TABLE statements
  * @param string $sTblEngine
  * @param string $sTblCollation
  * @return boolean true if import successful
  */
 	public function SqlImport($sSqlDump,
 	                          $sTablePrefix = '',
-	                          $bPreserve = true,
-	                          $sTblEngine = 'ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci',
-	                          $sTblCollation = ' collate utf8_unicode_ci')
+	                          $bPreserve    = true,
+	                          $sEngine      = 'MyISAM',
+	                          $sCollation   = 'utf8_unicode_ci')
 	{
+		$sCollation = ($sCollation != '' ? $sCollation : 'utf8_unicode_ci');
+		$aCharset = preg_split('/_/', $sCollation, null, PREG_SPLIT_NO_EMPTY);
+		$sEngine = 'ENGINE='.$sEngine.' DEFAULT CHARSET='.$aCharset[0].' COLLATE='.$sCollation;
+		$sCollation = ' collate '.$sCollation;
 		$retval = true;
 		$this->error = '';
 		$aSearch  = array('{TABLE_PREFIX}','{TABLE_ENGINE}', '{TABLE_COLLATION}');
-		$aReplace = array($sTablePrefix, $sTblEngine, $sTblCollation);
+		$aReplace = array($this->sTablePrefix, $sEngine, $sCollation);
 		$sql = '';
 		$aSql = file($sSqlDump);
 		while ( sizeof($aSql) > 0 ) {
@@ -400,21 +400,25 @@
  * @param string $sSqlDump link to the sql-dumpfile
  * @param string $sTablePrefix
- * @param bool $bPreserve set to true will ignore all DROP TABLE statements
- * @param string $sTblEngine
- * @param string $sTblCollation
+ * @param bool     $bPreserve   set to true will ignore all DROP TABLE statements
+ * @param string   $sEngine     can be 'MyISAM' or 'InnoDB'
+ * @param string   $sCollation  one of the list of available collations
  * @return boolean true if import successful
  */